import { LabelProps } from 'recharts';
import { ValueType, NameType } from 'recharts/types/component/DefaultTooltipContent';
import { ContentType } from 'recharts/types/component/Tooltip';
import { Margin } from 'recharts/types/util/types';
import { FeatureCollection } from 'geojson';
import { ReactNode } from 'react';

interface ButtonProps {
    text: string;
    onClick: () => void;
    color: string;
}

declare const Button: ({ text, onClick, color }: ButtonProps) => JSX.Element;

interface MultiAreaChartLegend {
    height?: number;
    show: boolean;
    fontSize?: number;
}
interface MultiAreaChartXAxis {
    values: string[];
    fontSize?: number;
}
interface MultiAreaChartYAxis {
    min?: number;
    max?: number;
    label?: LabelProps;
    fontSize?: number;
}
interface MultiAreaChartArea {
    label: string;
    key: string;
    stackIndex: number;
    stroke: string;
    fill: string;
    opacity: number;
    values: (number | undefined)[];
    dot?: boolean;
}
interface MultiAreaChartLine {
    label: string;
    key: string;
    stroke: string;
    width: number;
    opacity: number;
    values: (number | undefined)[];
    dot?: boolean;
}
interface MultiAreaChartData {
    xAxis: MultiAreaChartXAxis;
    yAxis?: MultiAreaChartYAxis;
    areas: MultiAreaChartArea[];
    lines?: MultiAreaChartLine[];
}
interface MultiAreaChartTooltip {
    active?: boolean;
    trigger?: 'click' | 'hover';
    customTooltip?: ContentType<ValueType, NameType>;
}
interface MultiAreaChartProps {
    data: MultiAreaChartData;
    legend: MultiAreaChartLegend;
    tooltip?: MultiAreaChartTooltip;
    /** Option for displaying area components with all zero values in the chart legend. Defaults to true */
    legendDisplayZeroValues?: boolean;
    margin?: Margin;
}

declare const MultiAreaChart: ({ data, legend, tooltip, legendDisplayZeroValues, margin, }: MultiAreaChartProps) => JSX.Element;

interface SlidingDateSelectorProps {
    minYear: number;
    maxYear: number;
    labelColor: string;
    primaryButtonColor?: string;
    primaryButtonSelectedColor?: string;
    secondaryButtonColor?: string;
    initialDate?: SelectedDate;
    onDateUpdated: (date: SelectedDate) => void;
    disableTodaySelection?: boolean;
    compact?: boolean;
}
interface SelectedDate {
    day?: number;
    month?: number;
    year: number;
}

declare const SlidingDateSelector: ({ labelColor, maxYear, minYear, onDateUpdated, primaryButtonColor, primaryButtonSelectedColor, secondaryButtonColor, initialDate, disableTodaySelection, compact, }: SlidingDateSelectorProps) => JSX.Element;

interface MapProps {
    id: string;
    tileUrl?: string;
    height: string;
    width: string;
    center: [x: number, y: number];
    zoom: number;
    icons?: MapIcon[];
    controls?: MapControls;
    highlightArea?: MapHighlightArea;
}
interface MapIcon {
    name: string;
    position: [x: number, y: number];
    src: string;
    anchor?: [x: number, y: number];
    anchorXUnits?: 'fraction' | 'pixels';
    anchorYUnits?: 'fraction' | 'pixels';
    scale?: number;
}
interface MapControls {
    showZoomButtons?: boolean;
}
interface MapHighlightArea {
    geoJson: FeatureCollection;
    strokeWidth: number;
    strokeColor: string;
    fillColor: string;
}

declare const Map: ({ id, height, width, center, zoom, icons, controls, tileUrl, highlightArea, }: MapProps) => JSX.Element;

interface IconSliderProps {
    valueInterval?: {
        min: number;
        max: number;
    };
    value: number | number[];
    stepSize?: number;
    label?: {
        value: string;
        position: LabelPosition;
    };
    orientation: SliderOrientation;
    icon?: ReactNode;
    sliderColor?: {
        thumbColor?: string;
        trackColor?: string;
        railColor?: string;
    };
    size?: {
        track?: number;
        thumb?: number;
        valueWidth?: string;
    };
    valueDisplay?: {
        valueFormatter: (value: number | number[]) => string;
        horizontalModePos?: HorizontalModeValuePosition;
    };
    valueFormatter?: (value: number | number[]) => string;
    onChange: (event: Event, newValue: number | number[]) => void;
}
declare enum HorizontalModeValuePosition {
    label = "label",
    end = "end"
}
declare enum LabelPosition {
    top = "top",
    bottom = "bottom"
}
declare enum SliderOrientation {
    vertical = "vertical",
    horizontal = "horizontal"
}

declare const IconSlider: ({ valueInterval, stepSize, label, orientation, icon, value, sliderColor, size, valueDisplay, onChange, }: IconSliderProps) => JSX.Element;

export { Button, HorizontalModeValuePosition, IconSlider, LabelPosition, Map, MultiAreaChart, SliderOrientation, SlidingDateSelector };
