import { LabelProps } from 'recharts'
import {
  NameType,
  ValueType,
} from 'recharts/types/component/DefaultTooltipContent'
import { ContentType } from 'recharts/types/component/Tooltip'
import { Margin } from 'recharts/types/util/types'

export interface MultiAreaChartLegend {
  height?: number
  show: boolean
  fontSize?: number
}

export interface MultiAreaChartXAxis {
  values: string[]
  fontSize?: number
}

export interface MultiAreaChartYAxis {
  min?: number
  max?: number
  label?: LabelProps
  fontSize?: number
}

export interface MultiAreaChartArea {
  label: string
  key: string
  stackIndex: number
  stroke: string
  fill: string
  opacity: number
  values: (number | undefined)[]
  dot?: boolean
}

export interface MultiAreaChartLine {
  label: string
  key: string
  stroke: string
  width: number
  opacity: number
  values: (number | undefined)[]
  dot?: boolean
}

export interface MultiAreaChartData {
  xAxis: MultiAreaChartXAxis
  yAxis?: MultiAreaChartYAxis
  areas: MultiAreaChartArea[]
  lines?: MultiAreaChartLine[]
}

export interface MultiAreaChartTooltip {
  active?: boolean
  trigger?: 'click' | 'hover'
  customTooltip?: ContentType<ValueType, NameType>
}

export interface MultiAreaChartProps {
  data: MultiAreaChartData
  legend: MultiAreaChartLegend
  tooltip?: MultiAreaChartTooltip
  /** Option for displaying area components with all zero values in the chart legend. Defaults to true */
  legendDisplayZeroValues?: boolean
  margin?: Margin
}
