import React from 'react'
import { StoryFn, Meta } from '@storybook/react'

import { default as MultiAreaChart } from '../../components/MultiAreaChart'
import { MultiAreaChartData } from '../../components/MultiAreaChart/MultiAreaChart.types'

const CustomTooltip = ({ active, payload, label }: any) => {
  if (active && payload && payload.length) {
    const total =
      parseInt(payload[0].payload['sun']) +
      parseInt(payload[0].payload['wind_land']) +
      parseInt(payload[0].payload['wind_sea'])
    const consumption = Math.floor(payload[0].payload['consumption'])
    const surplus = total - consumption
    const surplusStyle = surplus < 0 ? { color: 'red' } : { color: 'green' }
    const surplusComponent = <span style={surplusStyle}>{surplus}</span>
    return (
      <div style={{ background: '#fefefe', padding: 8, borderRadius: 4 }}>
        <b>{label}</b>
        <br />
        {`Sol: ${payload[0].payload['sun']}`}
        <br />
        {`Landvind: ${payload[0].payload['wind_land']}`}
        <br />
        {`Havvind: ${payload[0].payload['wind_sea']}`}
        <br />
        <b>{`Total: ${total}`}</b>
        <hr />
        {`Forbrug: ${Math.floor(payload[0].payload['consumption'])}`}
        <hr />
        Overskud: {surplusComponent}
        <hr />
        {`Potentiale: ${Math.floor(payload[0].payload['potential'])}`}
      </div>
    )
  }
  return null
}

const generateData = (): MultiAreaChartData => ({
  xAxis: {
    values: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'Maj',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Okt',
      'Nov',
      'Dec',
    ],
  },
  yAxis: {
    label: { value: 'Axis label', angle: -90 },
    min: 0,
    max: 4200,
  },
  areas: [
    {
      label: 'Potentiale',
      key: 'potential',
      stackIndex: 4,
      stroke: 'rgba(140, 230, 140, 1)',
      fill: 'rgba(120, 200, 120, 1)',
      opacity: 0.5,
      values: [
        4000, 4000, 4000, 4000, 4000, 4000, 4000, 4000, 4000, 4000, 4000, 4000,
      ],
      dot: false,
    },
    {
      key: 'consumption',
      label: 'Underskud',
      opacity: 0.5,
      stackIndex: 3,
      stroke: 'none',
      fill: 'red',
      values: [920, 900, 800, 744, 744, 1080, 584, 856, 754, 754, 666, 1000],
      dot: false,
    },
    {
      label: 'Sol',
      key: 'sun',
      stackIndex: 2,
      stroke: '#5F9EA0',
      fill: '#5F9EA0',
      opacity: 1,
      values: [100, 200, 100, 300, 400, 200, 150, 250, 454, 212, 242, 111],
      dot: false,
    },
    {
      label: 'Landvind',
      key: 'wind_land',
      stackIndex: 2,
      stroke: '#6689CC',
      fill: '#6669CC',
      opacity: 1,
      values: [423, 546, 344, 233, 452, 112, 424, 553, 222, 334, 232, 124],
      dot: false,
    },
    {
      label: 'Havvind',
      key: 'wind_sea',
      stackIndex: 2,
      stroke: 'dodgerblue',
      fill: 'dodgerblue',
      opacity: 1,
      values: [124, 434, 238, 296, 356, 322, 153, 427, 323, 632, 434, 333],
      dot: false,
    },
  ],
  lines: [
    {
      label: 'Forbrug',
      key: 'consumption',
      stroke: 'black',
      width: 2,
      opacity: 1,
      values: [920, 900, 800, 744, 744, 1080, 584, 856, 754, 754, 666, 1000],
      dot: false,
    },
  ],
})

export default {
  title: 'Charts/MultiAreaChart',
  component: MultiAreaChart,
  args: {
    legend: {
      show: true,
    },
    tooltip: {
      trigger: 'hover',
      active: true,
      customTooltip: <CustomTooltip />,
    },
    data: generateData(),
  },
} as Meta<typeof MultiAreaChart>

const Template: StoryFn<typeof MultiAreaChart> = args => (
  <div style={{ width: '100%', height: '600px' }}>
    <MultiAreaChart {...args} />
  </div>
)

export const EnergyConsumption = Template.bind({})

export const LegendWithoutZeroValues = Template.bind({})
LegendWithoutZeroValues.args = {
  data: ((gd: MultiAreaChartData) => {
    gd.areas[2].values = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    return gd
  })(generateData()),
  legendDisplayZeroValues: false,
}

export const MissingValues = Template.bind({})
MissingValues.args = {
  data: ((gd: MultiAreaChartData) => {
    gd.lines = [
      {
        label: 'Forbrug',
        key: 'consumption',
        stroke: 'black',
        width: 2,
        opacity: 1,
        values: [
          920,
          undefined,
          800,
          744,
          744,
          1080,
          584,
          856,
          754,
          754,
          666,
          1000,
        ],
        dot: false,
      },
    ]
    return gd
  })(generateData()),
}
