import React, { useState } from 'react'
import { StoryFn, Meta } from '@storybook/react'
import IconSlider from '../../components/IconSlider/IconSlider'
import imgPng from '../../img/solar.png'
import {
  IconSliderProps,
  SliderOrientation,
  LabelPosition,
  HorizontalModeValuePosition,
} from '../../components/IconSlider/IconSlider.types'

export default {
  title: 'Slider/IconSlider',
  component: IconSlider,
  args: {
    valueInterval: {
      min: 0,
      max: 100,
    },
    value: 10,
    stepSize: 10,
    label: { value: 'Solar', position: LabelPosition.bottom },
    orientation: SliderOrientation.vertical,
    valueDisplay: {
      valueFormatter: (value: number | number[]) => `%${value}`,
    },
    sliderColor: {
      trackColor: 'green',
      thumbColor: 'blue',
      railColor: 'yellow',
    },
    icon: <img src={imgPng} />,
    size: {
      track: 12,
      thumb: 28,
    },
    onChange: (event: Event, newValue: number | number[]) => {},
  },
} as Meta<typeof IconSlider>

// Mock parent component so that the slider component value changes
const MockParentComponent = (sliderProps: IconSliderProps) => {
  const [sliderValue, setSliderValue] = useState(sliderProps.value)
  const buildProps = () => {
    let newProps = { ...sliderProps }
    newProps.onChange = (eve, val) => {
      console.log('new val: ', val)
      setSliderValue(val)
    }
    newProps.value = sliderValue
    return newProps
  }
  return (
    <>
      <div>TOP ELEMENT</div>
      <IconSlider {...buildProps()} />
      <div>BOTTOM ELEMENT</div>
    </>
  )
}

const Story: StoryFn<typeof IconSlider> = args => (
  <div style={{ width: '600px', height: '400px' }}>
    <MockParentComponent {...args} />
  </div>
)

export const SingleValueVerticalIconSlider = Story.bind({})

export const RangeValueHorizontalIconSlider = Story.bind({})
RangeValueHorizontalIconSlider.args = {
  sliderColor: {
    trackColor: 'green',
    thumbColor: 'blue',
    railColor: 'red',
  },
  value: [10, 50],
  orientation: SliderOrientation.horizontal,
  valueDisplay: {
    valueFormatter: (value: number | number[]) => `%${value}`,
    horizontalModePos: HorizontalModeValuePosition.label,
  },
}

export const IconSliderWithLabelTop = Story.bind({})
IconSliderWithLabelTop.args = {
  value: [10, 50],
  orientation: SliderOrientation.horizontal,
  label: { value: 'Solar', position: LabelPosition.top },
  valueDisplay: {
    valueFormatter: (value: number | number[]) => `%${value}`,
    horizontalModePos: HorizontalModeValuePosition.label,
  },
}

export const FixedValueWidthSlider = Story.bind({})
FixedValueWidthSlider.args = {
  size: {
    track: 12,
    thumb: 28,
    valueWidth: '50px',
  },
  value: [10, 50],
  orientation: SliderOrientation.horizontal,
  valueDisplay: {
    valueFormatter: (value: number | number[]) => `%${value}`,
    horizontalModePos: HorizontalModeValuePosition.end,
  },
}

export const NoIconSlider = Story.bind({})
NoIconSlider.args = {
  icon: undefined,
  orientation: SliderOrientation.horizontal,
  valueDisplay: {
    valueFormatter: (value: number | number[]) => `%${value}`,
    horizontalModePos: HorizontalModeValuePosition.end,
  },
}

export const BiggerIconSlider = Story.bind({})
BiggerIconSlider.args = {
  size: {
    track: 24,
    thumb: 36,
    valueWidth: '50px',
  },
  orientation: SliderOrientation.horizontal,
  valueDisplay: {
    valueFormatter: (value: number | number[]) => `%${value}`,
    horizontalModePos: HorizontalModeValuePosition.end,
  },
}

export const SliderWithValueWidth = Story.bind({})
SliderWithValueWidth.args = {
  size: {
    valueWidth: '100px',
  },
  valueDisplay: {
    valueFormatter: (value: number | number[]) => `%${value}`,
    horizontalModePos: HorizontalModeValuePosition.end,
  },
}
